@@ -2,11 +2,11 @@ import logging
 import logging.config
 
 from bugsnag.handlers import BugsnagHandler
-from fluidattacks_core.logging import BATCH_LOGGING
+from fluidattacks_core.logging import PRODUCT_LOGGING
 
 
 def configure_logger(*, log_to_remote: bool) -> None:
-    logging.config.dictConfig(BATCH_LOGGING)
+    logging.config.dictConfig(PRODUCT_LOGGING)
 
     if log_to_remote:
         logger = logging.getLogger()
