@@ -136,6 +136,18 @@ def run_static_scanner(config_path: str) -> None:
     type=click.STRING,
     help="Docker registry password, if required.",
 )
+@click.option(
+    "--os",
+    default=None,
+    type=click.STRING,
+    help="Override the OS of the scan default: linux.",
+)
+@click.option(
+    "--arch",
+    default=None,
+    type=click.STRING,
+    help="Override the architecture of the scan default: arm64",
+)
 @click.option(
     "--aws-external-id",
     default=None,
