@@ -9,28 +9,17 @@ from labels.model.core import SourceType
 LOGGER = logging.getLogger(__name__)
 
 
-class BaseMetrics(NamedTuple):
-    files_amount: int
-    files_size: int
-
-
 class ExecutionMetrics(NamedTuple):
     """Metrics collected during execution.
 
     Attributes:
        group: Group identifier for the metrics
-       root: Root path identifier
        technique_time: Execution time in seconds
-       analyzed_files_amount: Number of files analyzed
-       analyzed_files_size: Total size of analyzed files in KB
 
     """
 
     group: str
-    root: str
     technique_time: float
-    analyzed_files_amount: int
-    analyzed_files_size: int
 
 
 def is_fluid_batch_env() -> bool:
@@ -40,7 +29,6 @@ def is_fluid_batch_env() -> bool:
 def process_sbom_metrics(
     execution_id: str | None,
     technique_time: float,
-    base_metrics: BaseMetrics,
     source_type: SourceType,
 ) -> None:
     try:
@@ -51,14 +39,9 @@ def process_sbom_metrics(
             and (execution_id_parts := execution_id.split("_"))
             and len(execution_id_parts) >= 3
         ):
-            group, *root, _ = execution_id_parts
             metrics = ExecutionMetrics(
-                group=group,
-                # In case root contained underscores
-                root=("_").join(root),
+                group=execution_id_parts[0],
                 technique_time=round(technique_time, 2),
-                analyzed_files_amount=int(base_metrics.files_amount),
-                analyzed_files_size=int(base_metrics.files_size // 1024),
             )
             send_metrics_to_cloudwatch(metrics)
     except Exception as exc:
@@ -76,7 +59,6 @@ def send_metrics_to_cloudwatch(execution_metrics: ExecutionMetrics) -> None:
     try:
         dimensions = [
             {"Name": "Group", "Value": execution_metrics.group},
-            {"Name": "Root", "Value": execution_metrics.root},
         ]
 
         metric_data = [
