@@ -1,5 +1,6 @@
 from labels.enrichers.elixir.get import get_hex_package
-from labels.model.package import HealthMetadata, Package
+from labels.model.metadata import HealthMetadata
+from labels.model.package import Package
 from labels.utils.licenses.validation import validate_licenses
 
 
