@@ -3,7 +3,8 @@ from datetime import datetime
 import pydantic
 
 from labels.enrichers.golang.get import fetch_latest_version_info, fetch_license_info
-from labels.model.package import HealthMetadata, Package
+from labels.model.metadata import HealthMetadata
+from labels.model.package import Package
 
 
 class GolangModuleEntry(pydantic.BaseModel):
