@@ -10,7 +10,7 @@ from labels.enrichers.utils import infer_algorithm
 from labels.model.ecosystem_data.java import JavaArchive
 from labels.model.metadata import Artifact, Digest, HealthMetadata
 from labels.model.package import Package
-from labels.parsers.cataloger.java.package import group_id_from_java_metadata
+from labels.parsers.cataloger.java.utils.group_id_resolver import group_id_from_java_metadata
 from labels.utils.licenses.validation import validate_licenses
 from labels.utils.strings import format_exception
 
