@@ -1,8 +1,12 @@
+import base64
 import json
+import logging
 import re
 import shutil
 import subprocess
 import tempfile
+from collections.abc import Iterator
+from contextlib import contextmanager
 from pathlib import Path
 from typing import Any
 
@@ -11,9 +15,12 @@ from labels.utils.exceptions import (
     DockerImageNotFoundError,
     InvalidImageReferenceError,
     SkopeoNotFoundError,
+    SyftNotFoundError,
 )
 from labels.utils.file import extract_tar_file
 
+LOGGER = logging.getLogger(__name__)
+
 
 def _format_image_ref(image_ref: str, *, daemon: bool = False) -> str:
     image_ref_pattern = (
@@ -154,6 +161,8 @@ def copy_image(  # noqa: PLR0913
     password: str | None = None,
     aws_creds: str | None = None,
     token: str | None = None,
+    os_override: str | None = None,
+    arch_override: str | None = None,
 ) -> bool:
     skopeo_path = _get_skopeo_path()
 
@@ -165,8 +174,7 @@ def copy_image(  # noqa: PLR0913
         "--dest-decompress",
         "--src-tls-verify=false",
         "--insecure-policy",
-        "--override-os",
-        "linux",
+        *build_override_args(os_override=os_override, arch_override=arch_override),
         formated_image_ref,
         f"dir:{dest_path}",
     ]
@@ -188,6 +196,8 @@ def extract_docker_image(  # noqa: PLR0913
     *,
     username: str | None = None,
     password: str | None = None,
+    os_override: str | None = None,
+    arch_override: str | None = None,
     token: str | None = None,
     aws_creds: str | None = None,
     daemon: bool = False,
@@ -201,6 +211,8 @@ def extract_docker_image(  # noqa: PLR0913
         dest_path=layers_dir_temp,
         username=username,
         password=password,
+        os_override=os_override,
+        arch_override=arch_override,
         token=token,
         aws_creds=aws_creds,
     )
@@ -214,11 +226,27 @@ def extract_docker_image(  # noqa: PLR0913
     return layers_dir_temp, manifest
 
 
+def build_override_args(
+    *,
+    os_override: str | None = None,
+    arch_override: str | None = None,
+) -> list[str]:
+    os_value = os_override if os_override is not None else "linux"
+    override_args = []
+    if os_value:
+        override_args.append(f"--override-os={os_value}")
+    if arch_override:
+        override_args.append(f"--override-arch={arch_override}")
+    return override_args
+
+
 def get_docker_image(  # noqa: PLR0913
     image_ref: str,
     *,
     username: str | None = None,
     password: str | None = None,
+    os_override: str | None = None,
+    arch_override: str | None = None,
     token: str | None = None,
     aws_creds: str | None = None,
     daemon: bool = False,
@@ -231,11 +259,9 @@ def get_docker_image(  # noqa: PLR0913
         skopeo_path,
         "inspect",
         "--tls-verify=false",
-        "--override-os",
-        "linux",
+        *build_override_args(os_override=os_override, arch_override=arch_override),
         formated_image_ref,
     ]
-
     authenticated_args = _build_inspect_auth_args(
         unauthenticated_args=command_args,
         username=username,
@@ -255,10 +281,13 @@ def get_docker_image(  # noqa: PLR0913
             result.stdout,
             object_hook=_custom_object_hook,
         )
-        if image_metadata:
-            image_metadata = image_metadata.model_copy(
+        image_metadata = (
+            image_metadata.model_copy(
                 update={"image_ref": image_ref},
             )
+            if image_metadata
+            else image_metadata
+        )
     except subprocess.CalledProcessError as error:
         raise DockerImageNotFoundError(image_ref, error.stderr.strip()) from error
     else:
@@ -270,6 +299,8 @@ def get_image_context(  # noqa: PLR0913
     image: ImageMetadata,
     username: str | None = None,
     password: str | None = None,
+    os_override: str | None = None,
+    arch_override: str | None = None,
     token: str | None = None,
     aws_creds: str | None = None,
     daemon: bool = False,
@@ -281,6 +312,8 @@ def get_image_context(  # noqa: PLR0913
         temp_dir,
         username=username,
         password=password,
+        os_override=os_override,
+        arch_override=arch_override,
         token=token,
         aws_creds=aws_creds,
         daemon=daemon,
@@ -297,3 +330,139 @@ def get_image_context(  # noqa: PLR0913
         manifest=manifest,
         image_ref=image.image_ref,
     )
+
+
+def _get_syft_path() -> str:
+    syft_path = shutil.which("syft")
+    if not syft_path:
+        raise SyftNotFoundError
+    return syft_path
+
+
+def _build_platform_arg(
+    *,
+    os_override: str | None = None,
+    arch_override: str | None = None,
+) -> list[str]:
+    os_value = os_override if os_override else "linux"
+    arch_override_value = arch_override if arch_override else "arm64"
+    return ["--platform", f"{os_value}/{arch_override_value}"]
+
+
+def _get_formatted_image(*, image_ref: str, daemon: bool = False) -> str:
+    image_ref_pattern = (
+        r"^(?:(?P<host>[\w\.\-]+(?:\:\d+)?)/)?"
+        r"(?P<namespace>(?:[\w\.\-]+(?:/[\w\.\-]+)*)?/)?"
+        r"(?P<image>[\w\.\-]+)(?::(?P<tag>[\w\.\-]+))?(?:@"
+        r"(?P<digest>sha256:[A-Fa-f0-9]{64}))?$"
+    )
+
+    syft_prefix = "docker" if daemon else "registry"
+    prefixes = {"registry": "docker://", "docker": "docker-daemon:"}
+    for prefix, prefix_value in prefixes.items():
+        if image_ref.startswith(prefix_value):
+            image_ref = image_ref.replace(prefix_value, "", 1)
+            syft_prefix = prefix
+            break
+
+    if re.match(image_ref_pattern, image_ref):
+        return f"{syft_prefix}:{image_ref}"
+
+    raise InvalidImageReferenceError(image_ref)
+
+
+@contextmanager
+def _syft_auth_env(
+    *,
+    image_ref: str | None = None,
+    username: str | None = None,
+    password: str | None = None,
+    aws_creds: str | None = None,
+    token: str | None = None,
+) -> Iterator[dict[str, str]]:
+    if username and password:
+        LOGGER.info("Setting DOCKER_USERNAME and DOCKER_PASSWORD environment variables for Syft")
+        yield {
+            "SYFT_REGISTRY_AUTH_USERNAME": username,
+            "SYFT_REGISTRY_AUTH_PASSWORD": password,
+        }
+        return
+
+    if image_ref and (auth := token or aws_creds):
+        config_dir = tempfile.mkdtemp(prefix=".syft")
+        LOGGER.debug("Creating temporary Docker config dir at %s", config_dir)
+
+        try:
+            docker_config_path = Path(config_dir, "config.json")
+            registry_url = image_ref.split("/", 1)[0]
+
+            encoded_auth = base64.b64encode(auth.encode("utf-8")).decode("utf-8")
+            docker_config = {
+                "auths": {
+                    registry_url: {
+                        "auth": encoded_auth,
+                    },
+                }
+            }
+
+            with docker_config_path.open("w", encoding="utf-8") as f:
+                json.dump(docker_config, f)
+            yield {
+                "DOCKER_CONFIG": config_dir,
+            }
+        finally:
+            LOGGER.debug("Cleaning up temporary DOCKER_CONFIG directory: %s", config_dir)
+            shutil.rmtree(config_dir, ignore_errors=True)
+
+        return
+
+    yield {}
+
+
+def get_docker_sbom(  # noqa: PLR0913
+    image_ref: str,
+    *,
+    username: str | None = None,
+    password: str | None = None,
+    os_override: str | None = None,
+    arch_override: str | None = None,
+    token: str | None = None,
+    aws_creds: str | None = None,
+    daemon: bool = False,
+) -> dict[str, Any]:
+    syft_path = _get_syft_path()
+    formatted_img = _get_formatted_image(image_ref=image_ref, daemon=daemon)
+
+    LOGGER.info("Retrieving SBOM for image: %s", image_ref)
+    LOGGER.info("Retrieving SBOM for image: %s", formatted_img)
+
+    command_args = [
+        syft_path,
+        "scan",
+        formatted_img,
+        *_build_platform_arg(os_override=os_override, arch_override=arch_override),
+        "-o",
+        "json",
+    ]
+
+    with _syft_auth_env(
+        image_ref=image_ref,
+        username=username,
+        password=password,
+        aws_creds=aws_creds,
+        token=token,
+    ) as syft_envs:
+        try:
+            result = subprocess.run(  # noqa: S603
+                command_args,
+                check=True,
+                capture_output=True,
+                text=True,
+                env=syft_envs,
+            )
+
+            sbom_data: dict[str, Any] = json.loads(result.stdout)
+        except subprocess.CalledProcessError as error:
+            raise DockerImageNotFoundError(image_ref, error.stderr.strip()) from error
+
+    return sbom_data
