@@ -7,7 +7,6 @@ AdvisoryRecord = tuple[
     str,  # source
     str,  # vulnerable_version
     str | None,  # severity_level
-    str | None,  # severity
     str | None,  # severity_v4
     str | None,  # epss
     str | None,  # details
@@ -17,6 +16,7 @@ AdvisoryRecord = tuple[
     int,  # auto_approve
     str | None,  # fixed_versions,
     int,  # kev_catalog
+    str | None,  # platform_version
 ]
 
 
@@ -41,12 +41,12 @@ class Advisory(BaseModel):
     package_manager: str
     cpes: list[str]
     severity_level: str = "Low"
+    platform_version: str | None = None
     fixed_versions: list[str] | None = None
     fix_metadata: AdvisoryFixMetadata | None = None
     details: str | None = None
     epss: float = 0.0
     percentile: float = 0.0
-    severity: str | None = None
     severity_v4: str | None = None
     cwe_ids: list[str] | None = None
     cve_finding: str | None = None
