@@ -1,10 +1,6 @@
 from typing import NamedTuple
 
-
-class PomContext(NamedTuple):
-    parent_info: dict[str, str] | None
-    parent_version_properties: dict[str, str] | None
-    manage_deps: dict[str, str] | None
+from labels.model.ecosystem_data.base import EcosystemDataModel
 
 
 class JavaPomParent(NamedTuple):
@@ -18,6 +14,7 @@ class JavaPomProject(NamedTuple):
     artifact_id: str | None = None
     version: str | None = None
     name: str | None = None
+    licenses: list[str] | None = None
     parent: JavaPomParent | None = None
 
 
@@ -33,7 +30,7 @@ class JavaPomProperties(NamedTuple):
     version: str | None = None
 
 
-class JavaArchive(NamedTuple):
+class JavaArchive(EcosystemDataModel):
     manifest: JavaManifest | None = None
     pom_properties: JavaPomProperties | None = None
     pom_project: JavaPomProject | None = None
