@@ -38,12 +38,6 @@ class ImageMetadata(BaseModel):
     model_config = ConfigDict(frozen=True)
 
 
-class LayerInfo(BaseModel):
-    id_: str
-    tar_full_path: str
-    metadata: dict[str, Any]
-
-
 class ImageContext(BaseModel):
     id: str
     name: str
