@@ -2,7 +2,7 @@ from packageurl import PackageURL
 
 
 def package_url(name: str, version: str) -> str:
-    return PackageURL(  # type: ignore
+    return PackageURL(  # type: ignore[misc]
         type="hex",
         namespace="",
         name=name,
