@@ -1,14 +1,13 @@
 import re
 from collections.abc import Iterator
-from typing import cast
-
-from packageurl import PackageURL
+from typing import Final
 
 from labels.model.file import Location, LocationReadCloser
-from labels.model.package import Language, Package, PackageType
+from labels.model.package import Package
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
+from labels.parsers.cataloger.golang.package_builder import new_go_package
 from labels.parsers.cataloger.utils import get_enriched_location
 
 GO_DIRECTIVE: re.Pattern[str] = re.compile(
@@ -32,38 +31,52 @@ GO_VERSION: re.Pattern[str] = re.compile(
     r"\ngo (?P<major>\d)\.(?P<minor>\d+)(\.\d+)?\n",
 )
 
-
-def package_url(module_name: str, module_version: str) -> str:
-    fields = module_name.split("/")
-
-    if all(not f.strip() for f in fields):
-        return ""
-
-    namespace = ""
-    name = ""
-    subpath = ""
-
-    if len(fields) == 1:
-        name = fields[0]
-    elif len(fields) == 2:
-        name = fields[1]
-        namespace = fields[0]
-    else:
-        name = fields[2]
-        namespace = "/".join(fields[:2])
-        subpath = "/".join(fields[3:])
-
-    return PackageURL(  # type: ignore[misc]
-        type="golang",
-        namespace=namespace,
-        name=name,
-        version=module_version,
-        qualifiers=None,
-        subpath=subpath,
-    ).to_string()
+MINIMUM_SUPPORTED_GO_VERSION: Final[tuple[int, int]] = (1, 17)
 
 
-def add_require(
+def parse_go_mod(
+    _resolver: Resolver | None,
+    _environment: Environment | None,
+    reader: LocationReadCloser,
+) -> tuple[list[Package], list[Relationship]]:
+    packages: list[Package] = []
+
+    file_content = reader.read_closer.read()
+    if _is_go_version_supported(file_content):
+        packages = list(_collect_packages(file_content, reader.location))
+
+    return packages, []
+
+
+def _collect_packages(
+    file_content: str,
+    location: Location,
+) -> Iterator[Package]:
+    go_req_directive: str = ""
+    replace_list: list[tuple[re.Match[str], int]] = []
+    req_dict: dict[str, Package] = {}
+
+    for line_number, line in enumerate(file_content.splitlines(), 1):
+        if matched := GO_REQ_MOD_DEP.search(line):
+            _add_required_package(matched, req_dict, line_number, location)
+        elif replace := GO_REP_DEP.search(line):
+            replace_list.append((replace, line_number))
+        elif not go_req_directive:
+            if directive := GO_DIRECTIVE.match(line):
+                go_req_directive = directive.group("directive")
+        elif go_req_directive == "replace":
+            if replace := GO_REPLACE.search(line):
+                replace_list.append((replace, line_number))
+                continue
+            go_req_directive = ""
+        elif matched := GO_MOD_DEP.search(line):
+            _add_required_package(matched, req_dict, line_number, location)
+        else:
+            go_req_directive = ""
+    return _apply_replace_directives(req_dict, replace_list, location)
+
+
+def _add_required_package(
     matched: re.Match[str],
     req_dict: dict[str, Package],
     line_number: int,
@@ -74,25 +87,18 @@ def add_require(
 
     new_location = get_enriched_location(parent_location, line=line_number, is_transitive=False)
 
-    req_dict[product] = Package(
-        name=product,
-        version=version,
-        type=PackageType.GoModulePkg,
-        locations=[new_location],
-        p_url=package_url(product, version),
-        ecosystem_data=None,
-        language=Language.GO,
-        licenses=[],
-    )
+    package = new_go_package(product, version, new_location)
+    if package:  # pragma: no branch
+        req_dict[product] = package
 
 
-def replace_req(
+def _apply_replace_directives(
     req_dict: dict[str, Package],
     replace_list: list[tuple[re.Match[str], int]],
     parent_location: Location,
 ) -> Iterator[Package]:
     for matched, line_number in replace_list:
-        match_dict = cast("dict[str, str]", matched.groupdict())
+        match_dict = matched.groupdict()
         old_pkg, old_version = match_dict["old_prod"], match_dict["old_ver"]
         repl_pkg, version = match_dict["new_prod"], match_dict["new_ver"]
 
@@ -107,59 +113,19 @@ def replace_req(
 
         new_location = get_enriched_location(parent_location, line=line_number, is_transitive=False)
 
-        req_dict[old_pkg] = Package(
-            name=repl_pkg,
-            version=version,
-            type=PackageType.GoModulePkg,
-            locations=[new_location],
-            p_url=package_url(repl_pkg, version),
-            language=Language.GO,
-            licenses=[],
-        )
+        package = new_go_package(repl_pkg, version, new_location)
+        if package:  # pragma: no branch
+            req_dict[old_pkg] = package
 
     return iter(req_dict.values())
 
 
-def resolve_go_deps(
-    content: str,
-    location: Location,
-) -> Iterator[Package]:
-    go_req_directive: str = ""
-    replace_list: list[tuple[re.Match[str], int]] = []
-    req_dict: dict[str, Package] = {}
-
-    for line_number, line in enumerate(content.splitlines(), 1):
-        if matched := GO_REQ_MOD_DEP.search(line):
-            add_require(matched, req_dict, line_number, location)
-        elif replace := GO_REP_DEP.search(line):
-            replace_list.append((replace, line_number))
-        elif not go_req_directive:
-            if directive := GO_DIRECTIVE.match(line):
-                go_req_directive = directive.group("directive")
-        elif go_req_directive == "replace":
-            if replace := GO_REPLACE.search(line):
-                replace_list.append((replace, line_number))
-                continue
-            go_req_directive = ""
-        elif matched := GO_MOD_DEP.search(line):
-            add_require(matched, req_dict, line_number, location)
-        else:
-            go_req_directive = ""
-    return replace_req(req_dict, replace_list, location)
-
-
-def parse_go_mod(
-    _: Resolver | None,
-    __: Environment | None,
-    reader: LocationReadCloser,
-) -> tuple[list[Package], list[Relationship]]:
-    packages = []
-    content = reader.read_closer.read()
+def _is_go_version_supported(content: str) -> bool:
     go_version = GO_VERSION.search(content)
     if not go_version:
-        return [], []
-    major = int(cast("dict[str, str]", go_version.groupdict())["major"])
-    minor = int(cast("dict[str, str]", go_version.groupdict())["minor"])
-    if major >= 2 or (major == 1 and minor >= 17):
-        packages = list(resolve_go_deps(content, reader.location))
-    return packages, []
+        return False
+
+    major = int(go_version.group("major"))
+    minor = int(go_version.group("minor"))
+
+    return (major, minor) >= MINIMUM_SUPPORTED_GO_VERSION
