@@ -1,21 +1,20 @@
 import re
-
-from pydantic import BaseModel, ValidationError
+from typing import NamedTuple
 
 from labels.model.ecosystem_data.java import JavaArchive, JavaPomProject
 from labels.model.file import Location, LocationReadCloser
-from labels.model.package import Language, Package, PackageType
+from labels.model.package import Package
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.java.package import package_url
-from labels.parsers.cataloger.utils import get_enriched_location, log_malformed_package_warning
+from labels.parsers.cataloger.java.utils.package_builder import JavaPackageSpec, new_java_package
+from labels.parsers.cataloger.utils import get_enriched_location
 
-# Constants
 QUOTE = r'["\']'
 NL = r"(\n?\s*)?"
 TEXT = r'[^"\']+'
-RE_LINE_COMMENT: re.Pattern[str] = re.compile(rf"^.*{NL}//.*$")
+LINE_COMMENT_RE = re.compile(rf"^.*{NL}//.*$")
+
 CONFIG_TO_DEV_STATUS = {
     "testRuntimeOnly": True,
     "testCompileOnly": True,
@@ -30,15 +29,7 @@ CONFIG_TO_DEV_STATUS = {
 }
 
 
-def is_comment(line: str) -> bool:
-    return (
-        line.strip().startswith("//")
-        or line.strip().startswith("/*")
-        or line.strip().endswith("*/")
-    )
-
-
-class LockFileDependency(BaseModel):
+class GradleDependency(NamedTuple):
     group: str
     name: str
     version: str
@@ -46,63 +37,72 @@ class LockFileDependency(BaseModel):
     line: int | None = None
 
 
-def create_java_archive(
-    dependency: LockFileDependency,
-    name: str,
-    version: str,
-) -> JavaArchive:
-    return JavaArchive(
-        pom_project=JavaPomProject(
-            group_id=dependency.group,
-            name=name,
-            artifact_id=name,
+def parse_gradle(
+    _resolver: Resolver | None,
+    _environment: Environment | None,
+    reader: LocationReadCloser,
+) -> tuple[list[Package], list[Relationship]]:
+    gradle_dependencies = _parse_dependencies(reader.read_closer.read())
+
+    packages = _collect_packages(gradle_dependencies, reader.location)
+
+    return packages, []
+
+
+def _collect_packages(
+    gradle_dependencies: list[GradleDependency], reader_location: Location
+) -> list[Package]:
+    packages: list[Package] = []
+
+    for dependency in gradle_dependencies:
+        name = dependency.name
+        version = dependency.version
+
+        is_dev = CONFIG_TO_DEV_STATUS.get(dependency.config, None)
+
+        new_location = get_enriched_location(reader_location, line=dependency.line, is_dev=is_dev)
+
+        ecosystem_data = JavaArchive(
+            pom_project=JavaPomProject(
+                group_id=dependency.group,
+                name=name,
+                artifact_id=name,
+                version=version,
+            ),
+        )
+
+        package_spec = JavaPackageSpec(
+            simple_name=name.rsplit(":", 1)[-1],
+            composed_name=name,
             version=version,
-        ),
-    )
+            location=new_location,
+            ecosystem_data=ecosystem_data,
+        )
+
+        package = new_java_package(package_spec)
+        if package:
+            packages.append(package)
+
+    return packages
 
 
-def create_package(
-    name: str,
-    version: str,
-    location: Location,
-    archive: JavaArchive,
-) -> Package:
-    return Package(
-        name=name,
-        version=version,
-        locations=[location],
-        language=Language.JAVA,
-        type=PackageType.JavaPkg,
-        ecosystem_data=archive,
-        p_url=package_url(name.rsplit(":", 1)[-1], version, archive),
-        licenses=[],
-    )
+def _parse_dependencies(file_content: str) -> list[GradleDependency]:
+    configs = _extract_gradle_configs(file_content)
+    maven_regexes = _build_regex_with_configs(configs)
+
+    dependencies = _get_block_deps(file_content, maven_regexes)
+
+    is_block_comment = False
+    for line_no, raw_line in enumerate(file_content.splitlines(), start=1):
+        clean_line, is_block_comment = _avoid_cmt(raw_line, is_block_cmt=is_block_comment)
+        dependency = _parse_line_dependency_line(clean_line, line_no, maven_regexes)
+        if dependency:
+            dependencies.append(dependency)
+
+    return dependencies
 
 
-def avoid_cmt(line: str, *, is_block_cmt: bool) -> tuple[str, bool]:
-    if RE_LINE_COMMENT.match(line):
-        line = line.split("//", 1)[0]
-    if is_block_cmt:
-        if "*/" in line:
-            is_block_cmt = False
-            line = line.split("*/", 1).pop()
-        else:
-            return "", is_block_cmt
-    if "/*" in line:
-        line_cmt_open = line.split("/*", 1)[0]
-        if "*/" in line:
-            line = line_cmt_open + line.split("*/", 1).pop()
-        else:
-            line = line_cmt_open
-            is_block_cmt = True
-    return line, is_block_cmt
-
-
-def get_line_number(content: str, match_start: int) -> int:
-    return content[:match_start].count("\n") + 2
-
-
-def extract_gradle_configs(content: str) -> set[str]:
+def _extract_gradle_configs(content: str) -> set[str]:
     config_pattern = re.compile(r"configurations\s*\{([^}]+)\}", re.DOTALL)
     custom_config_pattern = re.compile(r"\s*(\w+)\s*")
     configs = {
@@ -125,7 +125,7 @@ def extract_gradle_configs(content: str) -> set[str]:
     return configs
 
 
-def build_regex_with_configs(configs: set[str]) -> dict[str, re.Pattern[str]]:
+def _build_regex_with_configs(configs: set[str]) -> dict[str, re.Pattern[str]]:
     config_pattern = "|".join(configs)
 
     return {
@@ -160,7 +160,60 @@ def build_regex_with_configs(configs: set[str]) -> dict[str, re.Pattern[str]]:
     }
 
 
-def get_block_deps(content: str, regexes: dict[str, re.Pattern[str]]) -> list[LockFileDependency]:
+def _parse_line_dependency_line(
+    line: str, line_no: int, regexes: dict[str, re.Pattern]
+) -> GradleDependency | None:
+    for regex_key in ("RE_GRADLE_A", "RE_GRADLE_B"):
+        if match := regexes[regex_key].match(line):
+            if regex_key == "RE_GRADLE_A":
+                group = match.group("group")
+                product = f"{group}:{match.group('name')}"
+                version = match.group("version") or ""
+            else:
+                statement = match.group("statement")
+                product, version = (
+                    statement.rsplit(":", maxsplit=1)
+                    if statement.count(":") >= 2
+                    else (statement, "")
+                )
+                group = product.split(":")[0]
+
+            # Assuming a wildcard in Maven if the version is not found can # result in issues.
+            # https://gitlab.com/fluidattacks/universe/-/issues/5635
+            if not version or re.match(r"\${.*}", version):
+                return None
+
+            return GradleDependency(
+                group=group,
+                name=product,
+                version=version,
+                line=line_no,
+                config=match.group("config_name"),
+            )
+
+    return None
+
+
+def _avoid_cmt(line: str, *, is_block_cmt: bool) -> tuple[str, bool]:
+    if LINE_COMMENT_RE.match(line):
+        line = line.split("//", 1)[0]
+    if is_block_cmt:
+        if "*/" in line:
+            is_block_cmt = False
+            line = line.split("*/", 1).pop()
+        else:
+            return "", is_block_cmt
+    if "/*" in line:
+        line_cmt_open = line.split("/*", 1)[0]
+        if "*/" in line:
+            line = line_cmt_open + line.split("*/", 1).pop()
+        else:
+            line = line_cmt_open
+            is_block_cmt = True
+    return line, is_block_cmt
+
+
+def _get_block_deps(content: str, regexes: dict[str, re.Pattern[str]]) -> list[GradleDependency]:
     dependencies = []
 
     for block in regexes["BLOCK"].finditer(content):
@@ -170,15 +223,13 @@ def get_block_deps(content: str, regexes: dict[str, re.Pattern[str]]) -> list[Lo
             continue
 
         version = hit.group("version")
-        if version == "":
-            continue
 
         config = block.group("config_name")
 
-        line_no = get_line_number(content, block.start())
+        line_no = _get_line_number(content, block.start())
 
         dependencies.append(
-            LockFileDependency(
+            GradleDependency(
                 group=product.split(":")[0],
                 name=product,
                 version=version,
@@ -186,82 +237,9 @@ def get_block_deps(content: str, regexes: dict[str, re.Pattern[str]]) -> list[Lo
                 config=config,
             ),
         )
-    return dependencies
-
-
-def parse_dependencies(reader: LocationReadCloser) -> list[LockFileDependency]:
-    content = reader.read_closer.read()
-    configs = extract_gradle_configs(content)
-    maven_regexes = build_regex_with_configs(configs)
-    dependencies: list[LockFileDependency] = get_block_deps(content, maven_regexes)
-
-    is_block_cmt = False
-    for line_no, raw_line in enumerate(content.splitlines(), start=1):
-        line, is_block_cmt = avoid_cmt(raw_line, is_block_cmt=is_block_cmt)
-
-        if match := maven_regexes["RE_GRADLE_A"].match(line):
-            config = match.group("config_name")
-            group = match.group("group")
-            product = group + ":" + match.group("name")
-            version = match.group("version") or ""
-        elif match := maven_regexes["RE_GRADLE_B"].match(line):
-            config = match.group("config_name")
-            statement = match.group("statement")
-            product, version = (
-                statement.rsplit(":", maxsplit=1) if statement.count(":") >= 2 else (statement, "")
-            )
-            group = product.split(":")[0]
-        else:
-            continue
-
-        # Assuming a wildcard in Maven if the version is not found can
-        # result in issues.
-        # https://gitlab.com/fluidattacks/universe/-/issues/5635
-        if version == "" or re.match(r"\${.*}", version):
-            continue
-
-        dependencies.append(
-            LockFileDependency(
-                group=group, name=product, version=version, line=line_no, config=config
-            ),
-        )
 
     return dependencies
 
 
-def create_packages(
-    dependencies: list[LockFileDependency],
-    reader_location: Location,
-) -> list[Package]:
-    packages: list[Package] = []
-
-    for dependency in dependencies:
-        name = dependency.name
-        version = dependency.version
-
-        if not name or not version:
-            continue
-
-        is_dev = CONFIG_TO_DEV_STATUS.get(dependency.config, None)
-
-        new_location = get_enriched_location(reader_location, line=dependency.line, is_dev=is_dev)
-
-        archive = create_java_archive(dependency, name, version)
-
-        try:
-            package = create_package(name, version, new_location, archive)
-            packages.append(package)
-        except ValidationError as ex:
-            log_malformed_package_warning(new_location, ex)
-
-    return packages
-
-
-def parse_gradle(
-    _resolver: Resolver | None,
-    __: Environment | None,
-    reader: LocationReadCloser,
-) -> tuple[list[Package], list[Relationship]]:
-    dependencies = parse_dependencies(reader)
-    packages = create_packages(dependencies, reader.location)
-    return packages, []
+def _get_line_number(content: str, match_start: int) -> int:
+    return content[:match_start].count("\n") + 2
