@@ -1,12 +1,10 @@
-from typing import cast
-
 from labels.model.file import LocationReadCloser
 from labels.model.indexables import IndexedDict, ParsedValue
 from labels.model.package import Package
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.php.utils import new_package_from_composer
+from labels.parsers.cataloger.php.package_builder import new_package_from_composer
 from labels.parsers.cataloger.utils import get_enriched_location
 from labels.parsers.collection.json import parse_json_with_tree_sitter
 
@@ -14,40 +12,38 @@ EMPTY_DICT: IndexedDict[str, ParsedValue] = IndexedDict()
 
 
 def parse_composer_json(
-    _: Resolver | None,
-    __: Environment | None,
+    _resolver: Resolver | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    packages: list[Package] = []
-    relationships: list[Relationship] = []
-    content = cast(
-        "IndexedDict[str, ParsedValue]",
-        parse_json_with_tree_sitter(reader.read_closer.read()),
-    )
-    deps: IndexedDict[str, ParsedValue] = cast(
-        "IndexedDict[str, ParsedValue]",
-        content.get("require", EMPTY_DICT),
-    )
-    dev_deps: IndexedDict[str, ParsedValue] = cast(
-        "IndexedDict[str, ParsedValue]",
-        content.get("require-dev", EMPTY_DICT),
-    )
-    packages.extend(
-        [
-            *_get_packages(reader, deps, is_dev=False),
-            *_get_packages(reader, dev_deps, is_dev=True),
-        ]
-    )
-    return packages, relationships
+    file_content = parse_json_with_tree_sitter(reader.read_closer.read())
+    if not isinstance(file_content, IndexedDict):
+        return [], []
+
+    packages = _collect_packages(file_content, reader)
+
+    return packages, []
+
+
+def _collect_packages(
+    file_content: IndexedDict[str, ParsedValue], reader: LocationReadCloser
+) -> list[Package]:
+    deps = file_content.get("require")
+    dev_deps = file_content.get("require-dev")
+
+    return [
+        *_get_packages(reader, deps, is_dev=False),
+        *_get_packages(reader, dev_deps, is_dev=True),
+    ]
 
 
 def _get_packages(
     reader: LocationReadCloser,
-    dependencies: IndexedDict[str, ParsedValue],
+    dependencies: ParsedValue,
     *,
     is_dev: bool,
 ) -> list[Package]:
-    if not dependencies:
+    if not isinstance(dependencies, IndexedDict):
         return []
 
     items = dependencies.items()
@@ -64,7 +60,7 @@ def _get_packages(
         )
 
         package = new_package_from_composer(name=name, version=version, location=new_location)
-        if package:
+        if package:  # pragma: no branch
             packages.append(package)
 
     return packages
