@@ -1,12 +1,12 @@
 from typing import cast
 
 from labels.model.file import LocationReadCloser
-from labels.model.indexables import IndexedDict, ParsedValue
+from labels.model.indexables import IndexedDict, IndexedList, ParsedValue
 from labels.model.package import Package
 from labels.model.relationship import Relationship, RelationshipType
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.php.utils import new_package_from_composer
+from labels.parsers.cataloger.php.package_builder import new_package_from_composer
 from labels.parsers.cataloger.utils import get_enriched_location
 from labels.parsers.collection.json import parse_json_with_tree_sitter
 
@@ -14,27 +14,26 @@ EMPTY_DICT: IndexedDict[str, ParsedValue] = IndexedDict()
 
 
 def parse_composer_lock(
-    _: Resolver | None,
-    __: Environment | None,
+    _resolver: Resolver | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    package_json: IndexedDict[str, ParsedValue] = cast(
-        "IndexedDict[str, ParsedValue]",
-        parse_json_with_tree_sitter(reader.read_closer.read()),
-    )
+    file_content = parse_json_with_tree_sitter(reader.read_closer.read())
+    if not isinstance(file_content, IndexedDict):
+        return [], []
 
-    packages = _extract_packages(package_json, reader)
-    relationships = _extract_relationships(package_json, packages)
+    packages = _collect_packages(file_content, reader)
+    relationships = _collect_relationships(file_content, packages)
 
     return packages, relationships
 
 
-def _extract_packages(
-    package_json: IndexedDict[str, ParsedValue], reader: LocationReadCloser
+def _collect_packages(
+    file_content: IndexedDict[str, ParsedValue], reader: LocationReadCloser
 ) -> list[Package]:
     packages: list[Package] = []
 
-    for is_dev, raw_package in _get_all_packages_with_dev_flag(package_json):
+    for is_dev, raw_package in _get_all_packages_with_dev_flag(file_content):
         name = str(raw_package.get("name", "")) or None
         version = str(raw_package.get("version", "")) or None
 
@@ -55,7 +54,7 @@ def _extract_packages(
     return packages
 
 
-def _extract_relationships(
+def _collect_relationships(
     package_json: IndexedDict[str, ParsedValue], packages: list[Package]
 ) -> list[Relationship]:
     relationships: list[Relationship] = []
@@ -92,19 +91,27 @@ def _extract_relationships(
 def _get_all_packages_with_dev_flag(
     package_json: IndexedDict[str, ParsedValue],
 ) -> list[tuple[bool, IndexedDict[str, ParsedValue]]]:
-    production_packages = _get_packages_dict(package_json, "packages")
-    development_packages = _get_packages_dict(package_json, "packages-dev")
+    packages: list[tuple[bool, IndexedDict[str, ParsedValue]]] = []
 
-    return [
-        *[(False, package) for package in production_packages if isinstance(package, IndexedDict)],
-        *[(True, package) for package in development_packages if isinstance(package, IndexedDict)],
-    ]
+    production_packages = package_json.get("packages")
+    development_packages = package_json.get("packages-dev")
 
+    if isinstance(production_packages, IndexedList):
+        packages.extend(
+            [
+                (False, package)
+                for package in production_packages
+                if isinstance(package, IndexedDict)
+            ]
+        )
 
-def _get_packages_dict(
-    package_json: IndexedDict[str, ParsedValue], key: str
-) -> IndexedDict[str, ParsedValue]:
-    return cast(
-        "IndexedDict[str, ParsedValue]",
-        package_json.get(key, EMPTY_DICT),
-    )
+    if isinstance(development_packages, IndexedList):
+        packages.extend(
+            [
+                (True, package)
+                for package in development_packages
+                if isinstance(package, IndexedDict)
+            ]
+        )
+
+    return packages
