@@ -6,7 +6,7 @@ from labels.model.package import Package
 from labels.model.relationship import Relationship, RelationshipType
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.php.utils import new_package_from_composer
+from labels.parsers.cataloger.php.package_builder import new_package_from_composer
 from labels.parsers.cataloger.utils import get_enriched_location
 from labels.parsers.collection.json import parse_json_with_tree_sitter
 
@@ -14,41 +14,38 @@ EMPTY_LIST: IndexedList[ParsedValue] = IndexedList()
 
 
 def parse_installed_json(
-    _: Resolver | None,
-    __: Environment | None,
+    _resolver: Resolver | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    packages: list[Package] = []
-    relationships: list[Relationship] = []
-    package_json = parse_json_with_tree_sitter(reader.read_closer.read())
+    file_content = parse_json_with_tree_sitter(reader.read_closer.read())
+    if not isinstance(file_content, (IndexedDict, IndexedList)):  # pragma: no cover
+        return [], []
 
-    if not isinstance(package_json, (IndexedDict, IndexedList)):  # pragma: no cover
-        return packages, relationships
-
-    packages = _extract_packages(package_json, reader.location)
-    relationships = _extract_relationships(packages, package_json)
+    packages = _extract_packages(file_content, reader.location)
+    relationships = _extract_relationships(packages, file_content)
 
     return packages, relationships
 
 
 def _extract_packages(
-    package_json: IndexedDict[str, ParsedValue] | IndexedList[ParsedValue],
+    file_content: IndexedDict[str, ParsedValue] | IndexedList[ParsedValue],
     location: Location,
 ) -> list[Package]:
     packages = []
     dev_packages = EMPTY_LIST
 
     if (
-        isinstance(package_json, IndexedDict)
-        and "dev-package-names" in package_json
-        and isinstance(package_json["dev-package-names"], IndexedList)
+        isinstance(file_content, IndexedDict)
+        and "dev-package-names" in file_content
+        and isinstance(file_content["dev-package-names"], IndexedList)
     ):
-        dev_packages = package_json["dev-package-names"]
+        dev_packages = file_content["dev-package-names"]
 
     packages_list = (
-        package_json["packages"]
-        if isinstance(package_json, IndexedDict) and "packages" in package_json
-        else package_json
+        file_content["packages"]
+        if isinstance(file_content, IndexedDict) and "packages" in file_content
+        else file_content
     )
 
     for package in packages_list if isinstance(packages_list, IndexedList) else EMPTY_LIST:
@@ -77,13 +74,13 @@ def _extract_packages(
 
 
 def _extract_relationships(
-    packages: list[Package], package_json: IndexedDict[str, ParsedValue] | IndexedList[ParsedValue]
+    packages: list[Package], file_content: IndexedDict[str, ParsedValue] | IndexedList[ParsedValue]
 ) -> list[Relationship]:
     relationships = []
     packages_list = (
-        package_json["packages"]
-        if isinstance(package_json, IndexedDict) and "packages" in package_json
-        else package_json
+        file_content["packages"]
+        if isinstance(file_content, IndexedDict) and "packages" in file_content
+        else file_content
     )
 
     if not isinstance(packages_list, IndexedList):
