@@ -4,31 +4,39 @@ from labels.model.package import Package
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.python.utils import new_python_package
+from labels.parsers.cataloger.python.package_builder import new_python_package
 from labels.parsers.cataloger.utils import get_enriched_location
 from labels.parsers.collection import toml
 
 
 def parse_pipfile_deps(
     _resolver: Resolver | None,
-    _env: Environment | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    file_content = reader.read_closer.read()
-    toml_content: IndexedDict[str, ParsedValue] = toml.parse_toml_with_tree_sitter(file_content)
+    file_content = toml.parse_toml_with_tree_sitter(reader.read_closer.read())
 
-    toml_packages = toml_content.get("packages")
+    packages = _collect_packages(reader, file_content)
+
+    return packages, []
+
+
+def _collect_packages(
+    reader: LocationReadCloser, file_content: IndexedDict[str, ParsedValue]
+) -> list[Package]:
+    packages: list[Package] = []
+
+    toml_packages = file_content.get("packages")
     if not isinstance(toml_packages, IndexedDict):
-        return [], []
-
+        return packages
     packages = _get_packages(reader, toml_packages)
 
-    dev_deps = toml_content.get("dev-packages")
+    dev_deps = file_content.get("dev-packages")
     if isinstance(dev_deps, IndexedDict):
         dev_pkgs = _get_packages(reader, dev_deps, is_dev=True)
         packages.extend(dev_pkgs)
 
-    return packages, []
+    return packages
 
 
 def _get_packages(
