@@ -1,39 +1,37 @@
-from typing import cast
-
 from labels.model.file import LocationReadCloser
 from labels.model.indexables import IndexedDict, ParsedValue
 from labels.model.package import Package
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.python.utils import new_python_package
+from labels.parsers.cataloger.python.package_builder import new_python_package
 from labels.parsers.cataloger.utils import get_enriched_location
 from labels.parsers.collection.json import parse_json_with_tree_sitter
 
 
 def parse_pipfile_lock_deps(
     _resolver: Resolver | None,
-    _env: Environment | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    content = cast(
-        "IndexedDict[str, ParsedValue]",
-        parse_json_with_tree_sitter(reader.read_closer.read()),
-    )
-    deps: ParsedValue | None = content.get("default")
-    dev_deps: ParsedValue | None = content.get("develop")
-    packages = [
-        *_get_packages(reader, deps),
-        *_get_packages(reader, dev_deps, is_dev=True),
-    ]
+    file_content = parse_json_with_tree_sitter(reader.read_closer.read())
+    if not isinstance(file_content, IndexedDict):
+        return [], []
+
+    packages = _collect_packages(file_content, reader)
+
     return packages, []
 
 
-def _get_version(value: IndexedDict[str, ParsedValue]) -> str:
-    version = value.get("version")
-    if not isinstance(version, str):
-        return ""
-    return version.strip("=<>~^ ")
+def _collect_packages(
+    file_content: IndexedDict[str, ParsedValue], reader: LocationReadCloser
+) -> list[Package]:
+    deps: ParsedValue | None = file_content.get("default")
+    dev_deps: ParsedValue | None = file_content.get("develop")
+    return [
+        *_get_packages(reader, deps),
+        *_get_packages(reader, dev_deps, is_dev=True),
+    ]
 
 
 def _get_packages(
@@ -63,3 +61,10 @@ def _get_packages(
             packages.append(package)
 
     return packages
+
+
+def _get_version(value: IndexedDict[str, ParsedValue]) -> str:
+    version = value.get("version")
+    if not isinstance(version, str):
+        return ""
+    return version.strip("=<>~^ ")
