@@ -6,7 +6,7 @@ from labels.model.package import Package, PackageType
 from labels.model.relationship import Relationship, RelationshipType
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.python.utils import new_python_package
+from labels.parsers.cataloger.python.package_builder import new_python_package
 from labels.parsers.cataloger.utils import get_enriched_location
 from labels.parsers.collection import toml
 from labels.utils.strings import normalize_name
@@ -14,25 +14,23 @@ from labels.utils.strings import normalize_name
 
 def parse_poetry_lock(
     _resolver: Resolver | None,
-    _env: Environment | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    _content = reader.read_closer.read()
+    file_content = toml.parse_toml_with_tree_sitter(reader.read_closer.read())
 
-    toml_content: IndexedDict[str, ParsedValue] = toml.parse_toml_with_tree_sitter(_content)
-
-    packages = _parse_packages(toml_content, reader)
-    relationships = _parse_relationships(toml_content, packages)
+    packages = _collect_packages(file_content, reader)
+    relationships = _collect_relationships(file_content, packages)
 
     return packages, relationships
 
 
-def _parse_packages(
-    toml_content: IndexedDict[str, ParsedValue],
+def _collect_packages(
+    file_content: IndexedDict[str, ParsedValue],
     reader: LocationReadCloser,
 ) -> list[Package]:
     packages = []
-    toml_pkgs = toml_content.get("package")
+    toml_pkgs = file_content.get("package")
     if not isinstance(toml_pkgs, IndexedList):
         return []
 
@@ -87,7 +85,7 @@ def _find_package_by_name(packages: list[Package], name: str) -> Package | None:
     )
 
 
-def _parse_relationships(
+def _collect_relationships(
     toml_content: IndexedDict[str, ParsedValue],
     packages: list[Package],
 ) -> list[Relationship]:
