@@ -6,31 +6,39 @@ from labels.model.package import Package
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.python.utils import new_python_package
+from labels.parsers.cataloger.python.package_builder import new_python_package
 from labels.parsers.cataloger.utils import get_enriched_location
 from labels.parsers.collection.toml import parse_toml_with_tree_sitter
 
 
 def parse_pyproject_toml(
-    _: Resolver | None,
-    __: Environment | None,
+    _resolver: Resolver | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    content = parse_toml_with_tree_sitter(reader.read_closer.read())
+    file_content = parse_toml_with_tree_sitter(reader.read_closer.read())
 
-    packages = []
-    packages.extend(_parse_poetry_dependencies(content, reader))
-    packages.extend(_parse_uv_dependencies(content, reader))
+    packages = _collect_packages(file_content, reader)
 
     return packages, []
 
 
+def _collect_packages(
+    file_content: IndexedDict[str, ParsedValue],
+    reader: LocationReadCloser,
+) -> list[Package]:
+    return [
+        *_parse_poetry_dependencies(file_content, reader),
+        *_parse_uv_dependencies(file_content, reader),
+    ]
+
+
 def _parse_poetry_dependencies(
-    content: IndexedDict[str, ParsedValue],
+    file_content: IndexedDict[str, ParsedValue],
     reader: LocationReadCloser,
 ) -> list[Package]:
     packages: list[Package] = []
-    tool = content.get("tool")
+    tool = file_content.get("tool")
     if not isinstance(tool, IndexedDict):
         return packages
 
