@@ -9,7 +9,7 @@ from labels.model.package import Package
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.python.utils import new_python_package
+from labels.parsers.cataloger.python.package_builder import new_python_package
 from labels.parsers.cataloger.utils import get_enriched_location
 
 OPERATOR_ORDER = {"==": 1, "===": 1, "~=": 1, ">=": 2, ">": 2, "<": 3, "<=": 3}
@@ -23,24 +23,34 @@ class PythonRequirementsData(NamedTuple):
 
 def parse_requirements_txt(
     _resolver: Resolver | None,
-    _env: Environment | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    packages: list[Package] = []
-    relationships: list[Relationship] = []
-    deps_found = False
+    file_content = _safe_parse_requirements_txt(reader)
+    if not file_content:
+        return [], []
 
+    packages = _collect_packages(file_content, reader)
+
+    return packages, []
+
+
+def _safe_parse_requirements_txt(reader: LocationReadCloser) -> str | None:
     try:
-        content = reader.read_closer.read()
+        return reader.read_closer.read()
     except UnicodeDecodeError:
-        return packages, relationships
+        return None
 
-    for line_number, line in _split_lines_requirements(content):
+
+def _collect_packages(file_content: str, reader: LocationReadCloser) -> list[Package]:
+    packages: list[Package] = []
+    deps_found = False
+    for line_number, line in _split_lines_requirements(file_content):
         parsed_dependency_data = _get_parsed_dependency(line)
 
         if not parsed_dependency_data:
             if not deps_found and line_number > 3:
-                return packages, relationships
+                return packages
             continue
 
         deps_found = True
@@ -56,10 +66,10 @@ def parse_requirements_txt(
             version=parsed_dependency_data.version,
             location=new_location,
         )
-        if package:  # pragma: no cover
+        if package:  # pragma: no branch
             packages.append(package)
 
-    return packages, relationships
+    return packages
 
 
 def _split_lines_requirements(
