@@ -4,7 +4,7 @@ from labels.model.package import Package, PackageType
 from labels.model.relationship import Relationship, RelationshipType
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.python.utils import new_python_package
+from labels.parsers.cataloger.python.package_builder import new_python_package
 from labels.parsers.cataloger.utils import get_enriched_location
 from labels.parsers.collection import toml
 from labels.utils.strings import normalize_name
@@ -12,25 +12,23 @@ from labels.utils.strings import normalize_name
 
 def parse_uv_lock(
     _resolver: Resolver | None,
-    _env: Environment | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    _content = reader.read_closer.read()
+    file_content = toml.parse_toml_with_tree_sitter(reader.read_closer.read())
 
-    toml_content: IndexedDict[str, ParsedValue] = toml.parse_toml_with_tree_sitter(_content)
-
-    packages = _parse_packages(toml_content, reader)
-    relationships = _parse_relationships(toml_content, packages)
+    packages = _collect_packages(file_content, reader)
+    relationships = _collect_relationships(file_content, packages)
 
     return packages, relationships
 
 
-def _parse_packages(
-    toml_content: IndexedDict[str, ParsedValue],
+def _collect_packages(
+    file_content: IndexedDict[str, ParsedValue],
     reader: LocationReadCloser,
 ) -> list[Package]:
     packages = []
-    toml_pkgs = toml_content.get("package")
+    toml_pkgs = file_content.get("package")
     if not isinstance(toml_pkgs, IndexedList):
         return []
 
@@ -59,14 +57,15 @@ def _parse_packages(
     return packages
 
 
-def _parse_relationships(
+def _collect_relationships(
     toml_content: IndexedDict[str, ParsedValue],
     packages: list[Package],
 ) -> list[Relationship]:
-    relationships = []
+    relationships: list[Relationship] = []
+
     toml_pkgs = toml_content.get("package")
     if not isinstance(toml_pkgs, IndexedList):
-        return []
+        return relationships
 
     for package in toml_pkgs:
         dep_info = _get_dependencies(package, packages)
@@ -106,18 +105,19 @@ def _get_dependencies(
     if not isinstance(package_name, str):
         return None
 
-    _pkg = _find_package_by_name(packages, package_name)
+    package_found = _find_package_by_name(packages, package_name)
 
-    deps = package.get("dependencies")
-    if not isinstance(deps, IndexedList):
+    dependencies = package.get("dependencies")
+    if not isinstance(dependencies, IndexedList):
         return None
 
-    return _pkg, deps
+    return package_found, dependencies
 
 
 def _extract_dependency_name(dep: ParsedValue) -> str | None:
     if not isinstance(dep, IndexedDict):
         return None
+
     dep_name = dep.get("name")
     return str(dep_name) if isinstance(dep_name, str) else None
 
