@@ -6,7 +6,7 @@ from labels.model.package import Package
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.python.utils import new_python_package
+from labels.parsers.cataloger.python.package_builder import new_python_package
 
 
 class WheelEggPackageData(NamedTuple):
@@ -17,26 +17,32 @@ class WheelEggPackageData(NamedTuple):
 
 def parse_wheel_or_egg(
     resolver: Resolver,
-    _: Environment | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    packages: list[Package] = []
-    relationships: list[Relationship] = []
-
     package_data = _assemble_wheel_egg_package_data(resolver, reader.location)
     if not package_data:
-        return packages, relationships
+        return [], []
 
+    packages = _collect_packages(package_data, reader)
+
+    return packages, []
+
+
+def _collect_packages(
+    package_data: WheelEggPackageData, reader: LocationReadCloser
+) -> list[Package]:
+    packages: list[Package] = []
     package = new_python_package(
         name=package_data.name,
         version=package_data.version,
         location=reader.location,
         ecosystem_data=package_data.ecosystem_data,
     )
-    if package:  # pragma: no cover
+    if package:  # pragma: no branch
         packages.append(package)
 
-    return packages, relationships
+    return packages
 
 
 def _assemble_wheel_egg_package_data(
