@@ -8,7 +8,7 @@ from labels.model.package import Package
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
-from labels.parsers.cataloger.ruby.utils import new_gem_package
+from labels.parsers.cataloger.ruby.package_builder import new_gem_package
 from labels.parsers.cataloger.utils import get_enriched_location
 
 GEMFILE_DEP: re.Pattern[str] = re.compile(
@@ -24,18 +24,21 @@ GEM_LOCK_DEP: re.Pattern[str] = re.compile(
 
 
 def parse_gemfile(
-    _: Resolver | None,
-    __: Environment | None,
+    _resolver: Resolver | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    packages = []
+    packages = _collect_packages(reader.read_closer.read(), reader)
+
+    return packages, []
+
+
+def _collect_packages(file_content: str, reader: LocationReadCloser) -> list[Package]:
+    packages: list[Package] = []
     in_group_block = False
     end_line = ""
 
-    for line_number, line in enumerate(
-        reader.read_closer.read().splitlines(),
-        1,
-    ):
+    for line_number, line in enumerate(file_content.splitlines(), 1):
         if in_group_block:
             if line == end_line:
                 in_group_block = False
@@ -59,7 +62,7 @@ def parse_gemfile(
         ):
             packages.append(dependency)
 
-    return packages, []
+    return packages
 
 
 def _create_dependency(
