@@ -4,19 +4,31 @@ from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
 from labels.parsers.cataloger.graph_parser import Graph, NId, adj, node_to_str, parse_ast_graph
-from labels.parsers.cataloger.swift.utils import new_swift_package_manager_package
+from labels.parsers.cataloger.swift.package_builder import new_swift_package_manager_package
 from labels.parsers.cataloger.utils import get_enriched_location
 
 
 def parse_package_swift(
-    _: Resolver | None,
-    __: Environment | None,
+    _resolver: Resolver | None,
+    _environment: Environment | None,
     reader: LocationReadCloser,
 ) -> tuple[list[Package], list[Relationship]]:
-    content = reader.read_closer.read().encode("utf-8")
+    file_content = reader.read_closer.read().encode("utf-8")
+    if not file_content or not (graph := parse_ast_graph(file_content, "swift")):
+        return [], []
+
+    dependencies = _parse_dependencies(graph)
+    if dependencies is None:
+        return [], []
+
+    packages = _collect_packages(dependencies, graph, reader)
+
+    return packages, []
+
+
+def _parse_dependencies(graph: Graph) -> NId | None:
     dependencies = None
-    if not content or not (graph := parse_ast_graph(content, "swift")):
-        return ([], [])
+
     for node in graph.nodes:
         if (
             graph.nodes[node].get("label_type") == "call_expression"
@@ -33,18 +45,16 @@ def parse_package_swift(
                 ):
                     dependencies = graph.nodes[child]["label_field_value"]
                     break
-    if dependencies is None:
-        return ([], [])
-    return _get_dependencies(dependencies, graph, reader)
+
+    return dependencies
 
 
-def _get_dependencies(
+def _collect_packages(
     dep_node: NId,
     graph: Graph,
     reader: LocationReadCloser,
-) -> tuple[list[Package], list[Relationship]]:
+) -> list[Package]:
     packages: list[Package] = []
-    relationships: list[Relationship] = []
 
     for package_node in adj(graph, dep_node, depth=2):
         if _is_valid_package_node(graph, package_node):
@@ -61,7 +71,7 @@ def _get_dependencies(
             if package:
                 packages.append(package)
 
-    return packages, relationships
+    return packages
 
 
 def _is_valid_package_node(graph: Graph, package_node: NId) -> bool:
