@@ -338,6 +338,10 @@ def _nested_list(  #  noqa: PLR0913
             LOGGER.exception("Attempted to extend non-table type: %s", ".".join(build_key))
             return
         return
+
+    # TO-DO: Review the following unreachable code. When is_last=False,
+    # nested_list handles key traversal before calling _nested_list, so this branch
+    # is never executed
     data_val = data[key]
     if isinstance(data_val, IndexedDict):
         data = data_val
@@ -360,9 +364,7 @@ def nested_list(
         data = data_result
         if _nested_list_handle_fists_keys(data, key, is_last=is_last):
             data[(key, keys_node)] = (IndexedDict(), value_node or keys_node)
-            dict_value = data[key]
-            if isinstance(dict_value, IndexedDict):
-                data = dict_value
+            data = data[key]  # type: ignore[assignment]
             continue
         if _nested_list_handle_fists_keys_exists(data, key, is_last=is_last):
             data = data[key]  # type: ignore[assignment]
@@ -388,9 +390,9 @@ def nested_list(
 def _process_node(node: Node, data: IndexedDict[str, ParsedValue]) -> None:
     if node.type == "pair":
         node_results = handle_node(node)
-        if isinstance(node_results, tuple):
+        if isinstance(node_results, tuple):  # pragma: no branch
             key, value = node_results
-            if isinstance(key[0], str | list):
+            if isinstance(key[0], str | list):  # pragma: no branch
                 nested_dict(
                     data=data,
                     keys=key[0],
@@ -402,7 +404,7 @@ def _process_node(node: Node, data: IndexedDict[str, ParsedValue]) -> None:
         handle_table(node, data)
     elif node.type == "table_array_element":
         key, table_value = handle_table_array_element(node)
-        if isinstance(key[0], str | list):
+        if isinstance(key[0], str | list):  # pragma: no branch
             nested_list(
                 data=data,
                 keys=key[0],
