@@ -217,22 +217,13 @@ _NODE_HANDLERS = {
 }
 
 
-def _handle_node_result(
-    node_result: tuple[Node, ParsedValue | Exception],
-) -> tuple[Node, ParsedValue]:
-    node, value = node_result
-    if isinstance(value, Exception):
-        raise value
-    return node, value
-
-
 def handle_node(node: Node) -> tuple[Node, ParsedValue]:
     handler = _NODE_HANDLERS.get(node.type)
     if handler is None:
         raise UnexpectedNodeError(node.type)
 
     try:
-        return _handle_node_result(handler(node))
+        return handler(node)
     except Exception as e:
         if isinstance(
             e,
