@@ -53,36 +53,6 @@ bytes_size_table = {
 }
 
 
-def parse_bytes(size_human: str) -> int:
-    last_digit = 0
-    has_comma = False
-
-    for i, char in enumerate(size_human):
-        if not (char.isdigit() or char in {".", ","}):
-            break
-        if char == ",":
-            has_comma = True
-        last_digit = i + 1
-
-    num_str = size_human[:last_digit]
-    if has_comma:
-        num_str = num_str.replace(",", "")
-
-    try:
-        num = float(num_str)
-    except ValueError as exc:
-        error_message = f"Could not parse number: {num_str}"
-        raise ValueError(error_message) from exc
-
-    extra = size_human[last_digit:].strip().lower()
-    if extra in bytes_size_table:
-        num *= bytes_size_table[extra]
-        return int(num)
-
-    error_message = f"Unhandled size name: {extra}"
-    raise ValueError(error_message)
-
-
 def extract_tar_file(tar_path: str, out_path: str) -> None:
     with tarfile.open(tar_path, "r") as tar:
         for member in tar.getmembers():
